pub struct BaseStamp {
pub incarnation: u64,
pub generation: u64,
}Expand description
The state an action claims to be based on: the backend incarnation and the newest view generation the client has applied.
Fields
incarnation: u64generation: u64Trait Implementations
impl Copy for BaseStamp
Sourceimpl<'de> Deserialize<'de> for BaseStamp
impl<'de> Deserialize<'de> for BaseStamp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BaseStamp
impl StructuralPartialEq for BaseStamp